% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

clear all;



%% Setting up and running Example 1
% (1.) Setting parameter values (no buffering)
B_X   = 0;      % Additional proton buffering capacity
K_BX = 1e-7;    % Dissociation constant of additional proton buffer
par(1) = .0001;     % Vf_MDH
T = 25;             % Temperature

% (2.) Setting initial values
xo(1) = 3e-3;       % Malate (M)
xo(2) = 5e-4;       % NAD (M)
xo(3) = 3e-3;       % Oxaloacetate (M)
xo(4) = .5e-3;      % NADH
xo(5) = 10e-3;      % ATP
xo(6) = 1e-4;          % ADP
xo(7) = 0;          % AMP
xo(8) = 1e-7;       % [H] (M)
xo(9) = 1e-3;   % [Mg] (M)
xo(10) = 150e-3; % [K] (M)
Tspan = 15/40;
% (3.) Running for 15-second time course
[t,x] = ode23s(@MDH,[0:Tspan:15],xo,[],T,B_X,K_BX,par);
% (4.) Plotting results
figure(1); p = plot(t,x(:,1)*1e3,'k-',t,x(:,3)*1e3,'k:');
set(p,'linewidth',1.5);
text(2,3.15,'Malate','Fontsize',14);
text(2,2.85,'Oxaloacetate','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(2); p = plot(t,x(:,2)*1e3,'k-',t,x(:,4)*1e3,'k:');
set(p,'linewidth',1.5);
text(5,.75,'NAD','Fontsize',14);
text(5,.25,'NADH','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(3); p = plot(t,-log10(x(:,8)),'k-','LineWidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(4); p = plot(t,x(:,5)*1e3,'k-',t,x(:,6)*1e3,'k:');
set(p,'linewidth',1.5);
text(5,7,'ATP','Fontsize',14);
text(5,3,'ADP','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);

Table = array2table([t,x],'variableNames',{'Time','BISEN_mal','BISEN_NAD','BISEN_oca','BISEN_NADH','ATP','ADP','AMP','BISEN_H','BISEN_Mg','BISEN_K'});
S1 = 'MDHBisenOutput';
S2 = '.csv';
filename1 = strcat(S1);  % Append runtime to filename
filename = strcat(filename1,S2);
%filename = 'MDHBisenOutput.csv';
writetable(Table,filename);
%%
